@@ -247,20 +247,6 @@ def build_pipeline_labels(job_metadata, task_metadata, task_id_pattern=None):
   return labels
 
 
-def prepare_query_label_value(labels):
-  """Converts the label strings to contain label-appropriate characters.
-
-  Args:
-    labels: A set of strings to be converted.
-
-  Returns:
-    A list of converted strings.
-  """
-  if not labels:
-    return None
-  return [job_model.convert_to_label_chars(label) for label in labels]
-
-
 def parse_rfc3339_utc_string(rfc3339_utc_string):
   """Converts a datestamp from RFC3339 UTC to a datetime.
 
@@ -384,7 +370,11 @@ def _cancel_batch(batch_fn, cancel_fn, ops):
   for op in ops:
     op_name = op.get_field('internal-id')
     ops_by_name[op_name] = op
-    batch.add(cancel_fn(name=op_name, body={}), request_id=op_name)
+    try:
+      batch.add(cancel_fn(name=op_name, body={}), request_id=op_name)
+    except TypeError:
+      # Batch API delete_job method doesn't take a body parameter
+      batch.add(cancel_fn(name=op_name), request_id=op_name)
 
   # Cancel the operations
   batch.execute()
